@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2023 Maxime DOYEN
+ *  Copyright (C) 1995-2024 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -44,6 +44,16 @@ enum
 	NUM_LST_BUDGET
 };
 
+#define LST_BUDGET_POS_UNBUDGETED	G_MAXINT-2
+
+
+typedef enum
+{
+	REP_BUD_MODE_TOTAL,
+	REP_BUD_MODE_TIME
+} HbRepBudMode;
+
+
 struct repbudget_data
 {
 	GQueue		*txn_queue;
@@ -98,13 +108,6 @@ struct repbudget_data
 };
 
 
-enum
-{
-	BUDG_CATEGORY,
-	BUDG_SUBCATEGORY,
-};
-
-
 GtkWidget *repbudget_window_new(void);
 
 
